==> ui-react-1.1.497.tgz: package/esm/SectionCarousel/SectionCarousel.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["size", "values", "responsive", "fullHeight", "ItemProps", "CarouselProps", "className"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { useNavigate } from 'react-router-dom';
import { is, isEnvironment, textToInnerHTML } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import SectionElement from '../Section/Section';
import ButtonElement from '../Button';
import CarouselElement from '../Carousel';
import LineElement from '../Line';
import TypeElement from '../Type';
import useMediaQuery from '../useMediaQuery';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {},
  size_small: {
    '&.amaui-Carousel-root': {
      height: '340px'
    }
  },
  size_regular: {
    '&.amaui-Carousel-root': {
      height: '540px'
    }
  },
  size_large: {
    '&.amaui-Carousel-root': {
      height: '740px'
    }
  },
  fullHeight: {
    '&.amaui-Carousel-root': {
      height: '100vh'
    }
  },
  main: {
    padding: '0 96px',
    zIndex: '14'
  },
  item: {
    position: 'relative',
    height: '100%'
  },
  item_size_small: {
    padding: `${theme.methods.space.value(3, 'px')} ${theme.methods.space.value(3, 'px')}`
  },
  item_size_regular: {
    padding: `${theme.methods.space.value(6.75, 'px')} ${theme.methods.space.value(3, 'px')}`
  },
  item_size_large: {
    padding: `${theme.methods.space.value(9.25, 'px')} ${theme.methods.space.value(3, 'px')}`
  },
  text: {
    '&.amaui-Type-root': {
      color: 'white',
      mixBlendMode: 'difference'
    }
  },
  button: {
    transition: theme.methods.transitions.make('transform'),
    '&:active': {
      transform: 'scale(0.94)'
    }
  },
  background: {
    position: 'absolute',
    inset: '0',
    overflow: 'hidden',
    zIndex: '1'
  },
  backgroundImage: {
    backgroundSize: 'cover',
    backgroundPosition: 'center',
    backgroundRepeat: 'no-repeat'
  },
  backgroundVideo: {
    position: 'absolute',
    inset: '0',
    minHeight: '100%',
    minWidth: '100%',
    top: '50%',
    transform: 'translateY(-50%)',
    zIndex: '1'
  },
  backgroundOverlay: {
    position: 'absolute',
    inset: '0'
  },
  backgroundOverlayBlur: {
    backdropFilter: 'blur(12px)'
  },
  '@media only screen and (max-width: 640px)': {
    $main: {
      paddingInline: 72
    }
  }
}), {
  name: 'amaui-SectionCarousel'
});
const Element = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiSectionCarousel?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Section = React.useMemo(() => theme?.elements?.Section || SectionElement, [theme]);
  const Button = React.useMemo(() => theme?.elements?.Button || ButtonElement, [theme]);
  const Carousel = React.useMemo(() => theme?.elements?.Carousel || CarouselElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const {
      size: size_ = 'regular',
      values: values_ = [],
      responsive = true,
      fullHeight,
      ItemProps,
      CarouselProps,
      className
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const navigate = isEnvironment('browser') && useNavigate();
  const refs = {
    root: React.useRef()
  };
  const laptop = useMediaQuery('(max-width: 1440px)', {
    element: refs.root.current
  });
  const mobile = useMediaQuery('(max-width: 768px)', {
    element: refs.root.current
  });
  let size = size_;
  if (responsive) {
    if (laptop) size = 'regular';else if (mobile) size = 'small';
  }

  // Max 4
  const values = values_?.slice(0, 4);
  const getItem = React.useCallback((item, index) => {
    let styleBackground = {};
    const themed = [undefined, true].includes(item.themed);
    if (item.backgroundColor) {
      const palette = theme.palette.color[item.backgroundColor] || theme.methods.color(item.backgroundColor);
      styleBackground = _objectSpread(_objectSpread({}, styleBackground), {}, {
        backgroundColor: themed ? theme.methods.palette.color.value(undefined, 95, true, palette) : palette?.main
      });
    }
    if (is('array', item.backgroundGradient) && item.backgroundGradient.length >= 2) {
      const palette1 = theme.palette.color[item.backgroundGradient[0]] || theme.methods.color(item.backgroundGradient[0]);
      const palette2 = theme.palette.color[item.backgroundGradient[1]] || theme.methods.color(item.backgroundGradient[1]);
      const palette3 = theme.palette.color[item.backgroundGradient[2]] || theme.methods.color(item.backgroundGradient[2]);
      let backgroundImageStyle = '';
      if (item.backgroundGradient?.length === 2) {
        backgroundImageStyle = themed ? `linear-gradient(${theme.palette.light ? '130deg' : '330deg'}, ${theme.methods.palette.color.colorToRgb(palette1.main, 0.14)} 0%, ${theme.methods.palette.color.colorToRgb(palette2.main, 0.14)} 100%)` : `linear-gradient(${theme.palette.light ? '130deg' : '330deg'}, ${palette1.main} 0%, ${palette2.main} 100%)`;
      }
      if (item.backgroundGradient?.length === 3) {
        backgroundImageStyle = themed ? `linear-gradient(${theme.palette.light ? '130deg' : '330deg'}, ${theme.methods.palette.color.colorToRgb(palette1.main, 0.14)} 0%, ${theme.methods.palette.color.colorToRgb(palette2.main, 0.14)} 40%, ${theme.methods.palette.color.colorToRgb(palette3.main, 0.14)} 100%)` : `linear-gradient(${theme.palette.light ? '130deg' : '330deg'}, ${palette1.main} 0%, ${palette2.main} 40%, ${palette3.main} 100%)`;
      }
      styleBackground = _objectSpread(_objectSpread({}, styleBackground), {}, {
        backgroundImage: backgroundImageStyle
      });
    }
    if (item.backgroundImage) {
      const url = item.backgroundImage?.url || item.backgroundImage?.src || item.backgroundImage?.urlSmall || item.backgroundImage?.srcSmall || (is('string', item.backgroundImage) ? item.backgroundImage : '');
      if (url) {
        styleBackground = _objectSpread(_objectSpread({}, styleBackground), {}, {
          backgroundImage: `url('${url}')`
        });
      }
    }
    let styleOverlay = {};
    if (item.overlay) {
      const palette = theme.palette.color[item.overlay] || theme.methods.color(item.overlay);
      styleOverlay = _objectSpread(_objectSpread({}, styleOverlay), {}, {
        backgroundColor: themed ? theme.methods.palette.color.alpha(theme.methods.palette.color.value(undefined, 95, true, palette), 0.74) : palette?.main
      });
    }
    const urlVideo = item.backgroundVideo?.url || item.backgroundVideo?.src || item.backgroundVideo?.urlSmall || item.backgroundVideo?.srcSmall || (is('string', item.backgroundVideo) ? item.backgroundVideo : '');
    return /*#__PURE__*/React.createElement(Section, _extends({
      key: index,
      size: size,
      gap: 0,
      align: "flex-start",
      justify: "center",
      fullWidth: true
    }, ItemProps, {
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item'], ItemProps?.className, classes.item, classes[`item_size_${size}`]])
    }), /*#__PURE__*/React.createElement(Line, {
      gap: 1,
      align: "flex-start",
      justify: "center",
      fullWidth: true,
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item-main'], classes.main, classes.background, item.backgroundImage && styleBackground.backgroundImage && classes.backgroundImage]),
      style: _objectSpread({}, styleBackground)
    }, urlVideo && /*#__PURE__*/React.createElement("video", {
      autoPlay: true,
      muted: true,
      loop: true,
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item-background-video'], classes.backgroundVideo])
    }, /*#__PURE__*/React.createElement("source", {
      src: urlVideo
    })), item.overlay && /*#__PURE__*/React.createElement("div", {
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item-background-overlay'], classes.backgroundOverlay, item.overlayBlur && classes.backgroundOverlayBlur]),
      style: _objectSpread({}, styleOverlay)
    }), item.name && /*#__PURE__*/React.createElement(Type, _extends({
      version: size === 'large' ? 'd1' : size === 'regular' ? 'd2' : 'd3',
      fullWidth: true,
      dangerouslySetInnerHTML: {
        __html: textToInnerHTML(item.name)
      }
    }, item.propsName, {
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item-title'], item.propsName?.className, classes.text])
    })), item.description && /*#__PURE__*/React.createElement(Type, _extends({
      version: size === 'large' ? 'b1' : size === 'regular' ? 'b2' : 'b2',
      fullWidth: true,
      dangerouslySetInnerHTML: {
        __html: textToInnerHTML(item.description)
      }
    }, item.propsDescription, {
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item-description'], item.propsDescription?.className, classes.text])
    })), item.buttonText && /*#__PURE__*/React.createElement(Line, _extends({
      direction: "row",
      align: "center",
      justify: "flex-start",
      fullWidth: true
    }, item.propsButtonWrapper, {
      style: _objectSpread({
        marginTop: 12
      }, item.propsButtonWrapper?.style)
    }), /*#__PURE__*/React.createElement(Button, _extends({
      version: "filled",
      color: "primary",
      size: size === 'large' ? 'regular' : size === 'regular' ? 'small' : 'small',
      onClick: () => item.to ? navigate(item.to) : window.open(item.link, 'blank')
    }, item.propsButton, {
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item-button'], item.propsButton?.className, classes.button])
    }), item.buttonText || 'Click here'))));
  }, [theme, size]);
  return /*#__PURE__*/React.createElement(Section, _extends({
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    },
    maxWidth: false,
    padding: !values?.length,
    className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-root', `amaui-SectionCarousel-size-${size}`], className, classes.root])
  }, other), !!values?.length && /*#__PURE__*/React.createElement(Carousel, _extends({
    items: values?.map((item, index) => getItem(item, index)),
    autoPlay: true
  }, CarouselProps, {
    className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-items'], CarouselProps?.className, classes.items, classes[`size_${size}`], fullHeight && classes.fullHeight])
  })));
});
Element.displayName = 'amaui-SectionCarousel';
export default Element;

==> ui-react-1.1.498.tgz: package/esm/SectionCarousel/SectionCarousel.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["size", "values", "responsive", "fullHeight", "ItemProps", "CarouselProps", "className"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { useNavigate } from 'react-router-dom';
import { is, isEnvironment, textToInnerHTML } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import SectionElement from '../Section/Section';
import ButtonElement from '../Button';
import CarouselElement from '../Carousel';
import LineElement from '../Line';
import TypeElement from '../Type';
import useMediaQuery from '../useMediaQuery';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {},
  size_small: {
    '&.amaui-Carousel-root': {
      height: '340px'
    }
  },
  size_regular: {
    '&.amaui-Carousel-root': {
      height: '540px'
    }
  },
  size_large: {
    '&.amaui-Carousel-root': {
      height: '740px'
    }
  },
  fullHeight: {
    '&.amaui-Carousel-root': {
      height: '100vh'
    }
  },
  main: {
    padding: '0 96px',
    zIndex: '14'
  },
  item: {
    position: 'relative',
    height: '100%'
  },
  item_size_small: {
    padding: `${theme.methods.space.value(3, 'px')} ${theme.methods.space.value(3, 'px')}`
  },
  item_size_regular: {
    padding: `${theme.methods.space.value(6.75, 'px')} ${theme.methods.space.value(3, 'px')}`
  },
  item_size_large: {
    padding: `${theme.methods.space.value(9.25, 'px')} ${theme.methods.space.value(3, 'px')}`
  },
  text: {
    '&.amaui-Type-root': {
      color: 'white',
      mixBlendMode: 'difference'
    }
  },
  button: {
    transition: theme.methods.transitions.make('transform'),
    '&:active': {
      transform: 'scale(0.94)'
    }
  },
  background: {
    position: 'absolute',
    inset: '0',
    overflow: 'hidden',
    zIndex: '1'
  },
  backgroundImage: {
    backgroundSize: 'cover',
    backgroundPosition: 'center',
    backgroundRepeat: 'no-repeat'
  },
  backgroundVideo: {
    position: 'absolute',
    inset: '0',
    minHeight: '100%',
    minWidth: '100%',
    top: '50%',
    transform: 'translateY(-50%)',
    zIndex: '1'
  },
  backgroundOverlay: {
    position: 'absolute',
    inset: '0'
  },
  backgroundOverlayBlur: {
    backdropFilter: 'blur(12px)'
  },
  '@media only screen and (max-width: 640px)': {
    $main: {
      paddingInline: 72
    }
  }
}), {
  name: 'amaui-SectionCarousel'
});
const Element = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiSectionCarousel?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Section = React.useMemo(() => theme?.elements?.Section || SectionElement, [theme]);
  const Button = React.useMemo(() => theme?.elements?.Button || ButtonElement, [theme]);
  const Carousel = React.useMemo(() => theme?.elements?.Carousel || CarouselElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const {
      size: size_ = 'regular',
      values: values_ = [],
      responsive = true,
      fullHeight,
      ItemProps,
      CarouselProps,
      className
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const navigate = isEnvironment('browser') && useNavigate();
  const refs = {
    root: React.useRef()
  };
  const laptop = useMediaQuery('(max-width: 1440px)', {
    element: refs.root.current
  });
  const mobile = useMediaQuery('(max-width: 768px)', {
    element: refs.root.current
  });
  let size = size_;
  if (responsive) {
    if (laptop) size = 'regular';else if (mobile) size = 'small';
  }

  // Max 4
  const values = values_?.slice(0, 4);
  const getItem = React.useCallback((item, index) => {
    let styleBackground = {};
    const themed = [undefined, true].includes(item.themed);
    if (item.backgroundColor) {
      const palette = theme.palette.color[item.backgroundColor] || theme.methods.color(item.backgroundColor);
      styleBackground = _objectSpread(_objectSpread({}, styleBackground), {}, {
        backgroundColor: themed ? theme.methods.palette.color.value(undefined, 95, true, palette) : palette?.main
      });
    }
    if (is('array', item.backgroundGradient) && item.backgroundGradient.length >= 2) {
      const palette1 = theme.palette.color[item.backgroundGradient[0]] || theme.methods.color(item.backgroundGradient[0]);
      const palette2 = theme.palette.color[item.backgroundGradient[1]] || theme.methods.color(item.backgroundGradient[1]);
      const palette3 = theme.palette.color[item.backgroundGradient[2]] || theme.methods.color(item.backgroundGradient[2]);
      let backgroundImageStyle = '';
      if (item.backgroundGradient?.length === 2) {
        backgroundImageStyle = themed ? `linear-gradient(${theme.palette.light ? '130deg' : '330deg'}, ${theme.methods.palette.color.colorToRgb(palette1.main, 0.14)} 0%, ${theme.methods.palette.color.colorToRgb(palette2.main, 0.14)} 100%)` : `linear-gradient(${theme.palette.light ? '130deg' : '330deg'}, ${palette1.main} 0%, ${palette2.main} 100%)`;
      }
      if (item.backgroundGradient?.length === 3) {
        backgroundImageStyle = themed ? `linear-gradient(${theme.palette.light ? '130deg' : '330deg'}, ${theme.methods.palette.color.colorToRgb(palette1.main, 0.14)} 0%, ${theme.methods.palette.color.colorToRgb(palette2.main, 0.14)} 40%, ${theme.methods.palette.color.colorToRgb(palette3.main, 0.14)} 100%)` : `linear-gradient(${theme.palette.light ? '130deg' : '330deg'}, ${palette1.main} 0%, ${palette2.main} 40%, ${palette3.main} 100%)`;
      }
      styleBackground = _objectSpread(_objectSpread({}, styleBackground), {}, {
        backgroundImage: backgroundImageStyle
      });
    }
    if (item.backgroundImage) {
      const url = item.backgroundImage?.url || item.backgroundImage?.src || item.backgroundImage?.urlSmall || item.backgroundImage?.srcSmall || (is('string', item.backgroundImage) ? item.backgroundImage : '');
      if (url) {
        styleBackground = _objectSpread(_objectSpread({}, styleBackground), {}, {
          backgroundImage: `url('${url}')`
        });
      }
    }
    let styleOverlay = {};
    if (item.overlay) {
      const palette = theme.palette.color[item.overlay] || theme.methods.color(item.overlay);
      styleOverlay = _objectSpread(_objectSpread({}, styleOverlay), {}, {
        backgroundColor: themed ? theme.methods.palette.color.alpha(theme.methods.palette.color.value(undefined, 95, true, palette), 0.74) : palette?.main
      });
    }
    const urlVideo = item.backgroundVideo?.url || item.backgroundVideo?.src || item.backgroundVideo?.urlSmall || item.backgroundVideo?.srcSmall || (is('string', item.backgroundVideo) ? item.backgroundVideo : '');
    return /*#__PURE__*/React.createElement(Section, _extends({
      key: index,
      size: size,
      gap: 0,
      align: "flex-start",
      justify: "center",
      fullWidth: true
    }, ItemProps, {
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item'], ItemProps?.className, classes.item, classes[`item_size_${size}`]])
    }), /*#__PURE__*/React.createElement(Line, {
      gap: 1,
      align: "flex-start",
      justify: "center",
      fullWidth: true,
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item-main'], classes.main, classes.background, item.backgroundImage && styleBackground.backgroundImage && classes.backgroundImage]),
      style: _objectSpread({}, styleBackground)
    }, urlVideo && /*#__PURE__*/React.createElement("video", {
      autoPlay: true,
      muted: true,
      loop: true,
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item-background-video'], classes.backgroundVideo])
    }, /*#__PURE__*/React.createElement("source", {
      src: urlVideo
    })), item.overlay && /*#__PURE__*/React.createElement("div", {
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item-background-overlay'], classes.backgroundOverlay, item.overlayBlur && classes.backgroundOverlayBlur]),
      style: _objectSpread({}, styleOverlay)
    }), item.name && /*#__PURE__*/React.createElement(Type, _extends({
      version: size === 'large' ? 'd1' : size === 'regular' ? 'd2' : 'd3',
      fullWidth: true,
      dangerouslySetInnerHTML: {
        __html: textToInnerHTML(item.name)
      }
    }, item.propsName, {
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item-name'], item.propsName?.className, classes.text])
    })), item.description && /*#__PURE__*/React.createElement(Type, _extends({
      version: size === 'large' ? 'b1' : size === 'regular' ? 'b2' : 'b2',
      fullWidth: true,
      dangerouslySetInnerHTML: {
        __html: textToInnerHTML(item.description)
      }
    }, item.propsDescription, {
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item-description'], item.propsDescription?.className, classes.text])
    })), item.buttonText && /*#__PURE__*/React.createElement(Line, _extends({
      direction: "row",
      align: "center",
      justify: "flex-start",
      fullWidth: true
    }, item.propsButtonWrapper, {
      style: _objectSpread({
        marginTop: 12
      }, item.propsButtonWrapper?.style)
    }), /*#__PURE__*/React.createElement(Button, _extends({
      version: "filled",
      color: "primary",
      size: size === 'large' ? 'regular' : size === 'regular' ? 'small' : 'small',
      onClick: () => item.to ? navigate(item.to) : window.open(item.link, 'blank')
    }, item.propsButton, {
      className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-item-button'], item.propsButton?.className, classes.button])
    }), item.buttonText || 'Click here'))));
  }, [theme, size]);
  return /*#__PURE__*/React.createElement(Section, _extends({
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    },
    maxWidth: false,
    padding: !values?.length,
    className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-root', `amaui-SectionCarousel-size-${size}`], className, classes.root])
  }, other), !!values?.length && /*#__PURE__*/React.createElement(Carousel, _extends({
    items: values?.map((item, index) => getItem(item, index)),
    autoPlay: true
  }, CarouselProps, {
    className: classNames([staticClassName('SectionCarousel', theme) && ['amaui-SectionCarousel-items'], CarouselProps?.className, classes.items, classes[`size_${size}`], fullHeight && classes.fullHeight])
  })));
});
Element.displayName = 'amaui-SectionCarousel';
export default Element;
